@@ -27,7 +27,7 @@ def retry(loop=3,delay=5):
         @functools.wraps(func)
         def wrapper(*args, **kwargs):
             for i in range(1,loop+1):
-                logger.debug(f'第{i}次請求', args, kwargs)
+                logger.debug(f'第{i}次請求 {args} {kwargs}')
                 try:
                     return func(*args, **kwargs)
                 except ClientException as e:
